import React, { useState, useMemo, useEffect } from "react";
import PageTitle from "../../../../components/PageTitle";
import { useParams } from "react-router-dom";
import { useResourcesApi } from "../../api";
import { LoadingText } from "../../../../components";

const ResourceContainer = () => {
  const [state, setState] = useState(null);
  const [loading, setLoading] = useState(false);

  const params = useParams();
  const { getResource } = useResourcesApi();

  const isNew = useMemo(() => params.id === "new", [params.id]);

  useEffect(() => {
    if (isNew) return;
    const resourceId = parseInt(params.id);
    setLoading(true);
    getResource(resourceId).then((resource) => {
      setState(resource);
      setLoading(false);
    });
  }, [getResource, isNew, params.id]);

  if (loading || state === null) return <LoadingText lines={15} onPaper />;

  return (
    <>
      <PageTitle title={state.resourceName} />
      <>.................</>
    </>
  );
};

export default ResourceContainer;
